%iterate finds the location and angle of the next collision

%n is current iteration
%z is collection of possible values of t for the next iteration
%xo is x-value of last intersection
%yo is y-value of last intersection
%ao is horizontal angle of last intersection
%t1 is found value of t for current intersection
%newpiece is the number of the piece that is hit for current intersection
%data has 4 columns:  t, horizontal angle, incident angle, piece

%for example:  data(n-1,1) is t value for last intersection
%              ao is angle for last intersection

%find all possible values for t
z=[];

for j=1:size(table,1)
    %fun is tan(ao)*(x(t)-xo)-y(t)+yo
    fun=inline([num2str(tan(ao)),'*(',char(table{j,1}),'-',num2str(xo),')-(',char(table{j,2}),')+',num2str(yo)]);    
    a=table{j,3};   %lower bound of t for piece
    b=table{j,4};   %upper bound of t for piece
    
    %for pieces that are line segments
    if table{j,5}==1
       root=fzero(fun,(a+b)/2); %use average of a and b as starting point for fzero
       if root>=a & root<=b   %check if root is inside the interval
           z=[z,root];  %add root to z
       end

       
    %for pieces that are circular/elliptical arcs
    elseif table{j,5}==2    
        [cx,cy,rx,ry]=ellipseparam(table{j,1},table{j,2},table{j,3},table{j,4});  %finds x and y coordinates of center and radius of circle
        hit=0;  %indicates if the trajectory hits the arc or not
        if mod(ao,pi)==pi/2 %deals specifically with vertical lines
            if cx-rx<=xo & xo<=cx+rx
                hit=1;
                x1=xo;
                x2=xo;
                y1=-sqrt(rx^2*(1-x1^2/ry^2));
                y2=sqrt(rx^2*(1-x2^2/ry^2));
            end
        else
            m=tan(ao);  %slope of trajectory
            b0=-m*xo+m*cx+yo-cy;    %y-intercept of trajectory      y-(yo-cy)=m(x-(xo-cx))
            aq=rx^2*m^2+ry^2;   %a in the quadratic formula for roots
            bq=2*m*b0*rx^2;     %b in the quadratic formula for roots
            cq=b0^2*rx^2-rx^2*ry^2; %c in the quadratic formula for roots
            if bq^2-4*aq*cq>=0  %checks determinant to see if it hits
                hit=1;  %trajectory hits arc
                x1=(-bq-sqrt(bq^2-4*aq*cq))/2/aq;   %x-coordinate of intersection 1 (in different coordinate system)
                x2=(-bq+sqrt(bq^2-4*aq*cq))/2/aq;   %x-coordainte of intersection 2
                y1=m*x1+b0; %y-coordinate of intersection 1
                y2=m*x2+b0; %y-coordinate of intersection 2
            end
        end
        if hit  %if trajectory hits arc
            lt=mod(atan2((table{j,2}(table{j,3})-cy)/ry,(table{j,1}(table{j,3})-cx)/rx),2*pi);   %angle from center to lower bound point
            ut=mod(atan2((table{j,2}(table{j,4})-cy)/ry,(table{j,1}(table{j,4})-cx)/rx),2*pi);   %angle from center to upper bound point

            %if lt or ut are 0 or 2pi then you must pick either 0 or 2pi
            %depending on if it leaves the positive x-axis going up or down
            if abs(lt)<.001 | abs(lt-2*pi)<.001
                if table{j,2}((b-a)/4+a)>table{j,2}(a)  %if complete circle/ellipse is traced counterclockwise
                    lt=0;
                else    %table is traced clockwise
                    lt=2*pi;
                end
            end
            if abs(ut)<.001 | abs(ut-2*pi)<.001
                if table{j,2}((a-b)/4+b)>table{j,2}(b)  %if complete circle/ellipse is traced counterclockwise
                    ut=0;
                else    %table is traced clockwise
                    ut=2*pi;
                end
            end
            
            alpha=mod(atan2(y1/ry,x1/rx),2*pi);
            if lt<ut & lt<alpha & alpha<ut   %if alpha is between the lower and upper bounds for arcs (with lower less than upper)
                z=[z,(alpha-lt)/(ut-lt)*(b-a)+a];    %add root that is the same percent from lower to upper arc bounds as t
            end
            if lt>ut & lt>alpha & alpha>ut   %if alpha is between the lower and upper bounds for arcs (with upper less than lower)
                z=[z,(alpha-ut)/(lt-ut)*(a-b)+b];    %add root that is the same percent from lower to upper arc bounds as t
            end

            alpha=mod(atan2(y2/ry,x2/rx),2*pi);
            if lt<ut & lt<alpha & alpha<ut   %if alpha is between the lower and upper bounds for arcs (with lower less than upper)
                z=[z,(alpha-lt)/(ut-lt)*(b-a)+a];    %add root that is the same percent from lower to upper arc bounds as t
            end
            if lt>ut & lt>alpha & alpha>ut   %if alpha is between the lower and upper bounds for arcs (with upper less than lower)
                z=[z,(alpha-ut)/(lt-ut)*(a-b)+b];    %add root that is the same percent from lower to upper arc bounds as t
            end
        end

    %for pieces that are not segments or arcs
    else
        root=fzero(fun,a);  %use fzero starting at lower bound
        if root>a & root<b  %if root is between lower and upper bounds
            z=[z,root]; %add root to list
        end
        root=fzero(fun,b);  %use fzero starting at upper bound
        if root>a & root<b  %if root is between lower and upper bounds
            z=[z,root]; %add root to list
        end
        if fun(a)*fun(b)<0  %if endpoints have different signs
            root=fzero(fun,[a,b]);  %use fzero on interval
        else    %if endpoints have same sign
            root=fzero(fun,(a+b)/2);    %use fzero starting at midpoint
        end
        if root>a & root<b  %if root is between lower and upper bounds
            z=[z,root]; %add root to list
            if fun(root-(b-a)/100)*fun(a)<0 %check if sign is different at the lower bound and just to the left of the root
                root=fzero(fun,[a,root-(b-a)/20]);  %use fzero on this interval
                z=[z,root]; %add root to list
            end
            if fun(root+(b-a)/100)*fun(b)<0 %check if sign is different at the upper bound and just to the right of the root
                root=fzero(fun,[root+(b-a)/20,b]);  %use fzero on this interval
                z=[z,root]; %add root to list
            end
        end
    end
end
zz=z;

    if n~=1
        z=z(find(abs(z-data(n-1,1))>10^-5));  %remove root that corresponds to the particle's current position
    end
    
    remove=[];  %index values of z for bad roots
    %remove roots that correspond to the particle going the wrong direction
    %from the collision (passing through the barrier)
    if abs(mod(ao,pi)-pi/2)<100*eps  %deals specially with vertical trajectories
        for k=1:size(z,2)
            if (table{piece(z(k)),2}(z(k))-yo)*sin(ao)<0    %if root corresponds to opposite direction
                remove=[remove,k];
            end
        end
    else
        for k=1:size(z,2)   %deals with all non-vertical trajectories
            if (table{piece(z(k)),1}(z(k))-xo)*cos(ao)<0    %if root corresponds to opposite direction
                remove=[remove,k];
            end
        end
    end
    z(remove)=[];
    
    
    %find the value of possible values of t that has minimum distance from
    %last point
    if size(z,2)~=1
        distance=zeros(1,size(z,2));
        for k=1:size(z,2)
            i=piece(z(k));
            distance(1,k)=(xo-table{i,1}(z(k))).^2+(yo-table{i,2}(z(k))).^2;
        end
        distance(find(distance<10^-8))=inf;   %remove any values corresponding to no movement
        if length(find(distance==min(distance)))~=1 %if there is more than 1 closest point just pick the 1st one
            k=find(distance==min(distance));
            data(n,1)=z(k(1));
        else
           try
               data(n,1)=z(find(distance==min(distance)));  %store z value with minimum distance as t for this iteration
           catch
               'did not find all of the roots'
               handles.done=1;
           end
       end
    else
        data(n,1)=z;  %store z value as correct t value for this iteration
    end
    t1=data(n,1);   %t1 is t location of this collision
    data(n,4)=piece(t1); %which piecewise function of the table t is located in
    newpiece=data(n,4);  %newpiece is the number of the piecewise function that is hit

    %determines if it hit a corner or not by checking if t is near the
    %bounds of the piece it is on and then making sure the piece does not
    %loop back onto itself there
    if (t1-table{newpiece,3}<10^-8 | table{newpiece,4}-t1<10^-8) & (abs(table{newpiece,1}(table{newpiece,3})-table{newpiece,1}(table{newpiece,4}))>10^-8 | abs(table{newpiece,2}(table{newpiece,3})-table{newpiece,2}(table{newpiece,4}))>10^-8)
        %collision with corner detected
        j=1;    %index of other piece that makes up the corner

        x=inline(char(diff(eval(char(table{newpiece,1})),t)));   %x'(t) for new piece
        y=inline(char(diff(eval(char(table{newpiece,2})),t)));   %y'(t) for new piece
        
        if t1-table{newpiece,3}<10^-8   %if hit the corner corresponding lower values of t for the piece
            while abs(table{j,1}(table{j,4})-table{newpiece,1}(t1))>10^-8  | abs(table{j,2}(table{j,4})-table{newpiece,2}(t1))>10^-8  %checks if x and y distances from upper endpoint of piece to point are large
                j=j+1;  %trying to find piece that is the other side of the corner
            end

            xj=inline(char(diff(eval(char(table{j,1})),t)));        %x'(t) for j piece 
            yj=inline(char(diff(eval(char(table{j,2})),t)));        %y'(t) for j piece 
            
            %calculates the reflection angle for bouncing off the corner            
            data(n,2)=atan2(y(table{newpiece,3}),x(table{newpiece,3}))+atan2(yj(table{j,4}),xj(table{j,4}))-ao;

        else
            while abs(table{j,1}(table{j,3})-table{newpiece,1}(t1))>10^-8 | abs(table{j,2}(table{j,3})-table{newpiece,2}(t1))>10^-8  %checks if x and y distances from upper endpoint of piece to point are large
                j=j+1;  %trying to find piece that is the other side of the corner
            end
            
            xj=inline(char(diff(eval(char(table{j,1})),t)));        %x'(t) for j piece 
            yj=inline(char(diff(eval(char(table{j,2})),t)));        %y'(t) for j piece 
 
            %calculates the reflection angle for bouncing off the corner
            data(n,2)=atan2(y(table{newpiece,4}),x(table{newpiece,4}))+atan2(yj(table{j,3}),xj(table{j,3}))-ao;

            
        end
        data(n,2)=mod(data(n,2),2*pi); %move reflection angle to the principel value
        data(n,3)=NaN;  %store incident angle as non-existing for corners
    else
        %non-corner collision
        at=subs(d(newpiece),t1);  %angle of tangent line to table at point of collision
        data(n,2)=-ao+2*at; %exiting horizontal angle
        data(n,3)=mod(-ao+pi/2+at,pi);  %incident angle
        if data(n,3)>pi/2
            data(n,3)=data(n,3)-pi;  %incident angle in correct interval
        end
    end
    if data(n,2)>pi
        data(n,2)=data(n,2)-2*pi;  %correcting horizontal angle if not principle value
    end